@@ -167,8 +167,10 @@ by whitespace.  When FILE1 or FILE2 (not both) is -, read standard input.\n\
   -v SIDE           like -a SIDE, but suppress joined output lines\n\
   -1 FIELD          join on this FIELD of file 1\n\
   -2 FIELD          join on this FIELD of file 2\n\
-      --help        display this help and exit\n\
-      --version     output version information and exit\n\
+"), stdout);
+      fputs (HELP_OPTION_DESCRIPTION, stdout);
+      fputs (VERSION_OPTION_DESCRIPTION, stdout);
+      fputs (_("\
 \n\
 "), stdout);
       fputs (_("\
